@@ -78,11 +78,11 @@ macro_rules! trace_named_parameter_not_found {
 pub mod engine {
   use crate::feel::errors::*;
   use crate::feel::eval_bif;
-  use dmntk_common::{null_with_trace, Result, Stringify};
-  use dmntk_feel::bif::Bif;
-  use dmntk_feel::context::FeelContext;
-  use dmntk_feel::values::{FunctionBody, Value, Values, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE};
-  use dmntk_feel::{
+  use dmntk_feel_parser::dmntk_feel::bif::Bif;
+  use dmntk_feel_parser::dmntk_feel::context::FeelContext;
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::{null_with_trace, Result, Stringify};
+  use dmntk_feel_parser::dmntk_feel::values::{FunctionBody, Value, Values, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE};
+  use dmntk_feel_parser::dmntk_feel::{
     is_integer, round_half_to_even, subtract, AstNode, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelType, FeelYearsAndMonthsDuration, Name,
     OptAstNode, Scope,
   };
