@@ -19,9 +19,9 @@
 /// Built-in functions with named parameters.
 pub mod named {
   use crate::trace_named_parameter_not_found;
-  use dmntk_common::Result;
-  use dmntk_feel::values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE};
-  use dmntk_feel::Name;
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+  use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE};
+  use dmntk_feel_parser::dmntk_feel::Name;
 
   lazy_static! {
     static ref NAME_DATE: Name = Name::from("date");
@@ -513,9 +513,9 @@ pub mod named {
 pub mod positional {
   use crate::feel::evaluate;
   use crate::trace_invalid_number_of_parameters;
-  use dmntk_common::Result;
-  use dmntk_feel::values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE};
-  use dmntk_feel::{AstNode, Scope};
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+  use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE};
+  use dmntk_feel_parser::dmntk_feel::{AstNode, Scope};
 
   pub fn abs(scope: &Scope, positional_parameters: &[AstNode]) -> Result<Value> {
     match positional_parameters.len() {
@@ -1265,10 +1265,10 @@ pub mod positional {
 pub mod core {
   use crate::feel::evaluate_equals;
   use crate::{trace_invalid_value, trace_invalid_value_type};
-  use dmntk_common::Stringify;
-  use dmntk_feel::values::Value::YearsAndMonthsDuration;
-  use dmntk_feel::values::{Value, Values, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE};
-  use dmntk_feel::{round_half_to_even, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelYearsAndMonthsDuration};
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::Stringify;
+  use dmntk_feel_parser::dmntk_feel::values::Value::YearsAndMonthsDuration;
+  use dmntk_feel_parser::dmntk_feel::values::{Value, Values, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE};
+  use dmntk_feel_parser::dmntk_feel::{round_half_to_even, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelYearsAndMonthsDuration};
   use regex::Regex;
   use std::convert::TryFrom;
 
@@ -2378,7 +2378,7 @@ pub mod core {
 #[cfg(test)]
 mod tests {
   use crate::feel::eval_bif::core::substring;
-  use dmntk_feel::values::{Value, VALUE_NULL};
+  use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
 
   #[test]
   fn test_substring() {
