@@ -15,10 +15,10 @@
  */
 
 use self::errors::*;
-use dmntk_common::{null_with_trace, Result};
-use dmntk_feel::context::FeelContext;
-use dmntk_feel::values::Value;
-use dmntk_feel::{AstNode, FeelType, Scope};
+use dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_feel_parser::dmntk_feel::dmntk_common::{null_with_trace, Result};
+use dmntk_feel_parser::dmntk_feel::values::Value;
+use dmntk_feel_parser::dmntk_feel::{AstNode, FeelType, Scope};
 
 mod eval;
 mod eval_bif;
@@ -76,7 +76,7 @@ pub fn evaluate_context(scope: &Scope, input: &str) -> Result<FeelContext> {
 
 /// Definitions of errors reported by `FEEL` evaluator.
 mod errors {
-  use dmntk_common::DmntkError;
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
 
   #[derive(Debug, PartialEq)]
   pub enum FeelEvaluatorError {
