@@ -1,5 +1,21 @@
+/*
+ * DMNTK - Decision Model and Notation Toolkit
+ *
+ * FEEL and DMN model evaluator.
+ *
+ * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ */
+
 use super::*;
-use dmntk_feel::FeelTime;
+use dmntk_feel_parser::dmntk_feel::FeelTime;
 use std::f64::consts::LN_10;
 use std::ops::{Div, Mul};
 
