@@ -14,8 +14,8 @@
  * SOFTWARE.
  */
 
-use dmntk_feel::values::Value;
-use dmntk_feel::{AstNode, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelYearsAndMonthsDuration, Scope};
+use dmntk_feel_parser::dmntk_feel::values::Value;
+use dmntk_feel_parser::dmntk_feel::{AstNode, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelYearsAndMonthsDuration, Scope};
 
 mod built_in_functions;
 mod textual_expression;
