@@ -14,9 +14,7 @@
  * SOFTWARE.
  */
 
-extern crate dmntk_common;
 extern crate dmntk_examples;
-extern crate dmntk_feel;
 extern crate dmntk_feel_parser;
 extern crate dmntk_model;
 extern crate dmntk_recognizer;
