@@ -15,9 +15,9 @@
  */
 
 use crate::model::errors::*;
-use dmntk_common::Result;
-use dmntk_feel::context::FeelContext;
-use dmntk_feel::values::{Value, VALUE_NULL};
+use dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
 use dmntk_model::model::Definitions;
 
 /// Evaluates a decision service specified by name.
